pub trait MapFn<C: Ctx, E: UserEvent>:
Debug
+ Default
+ Send
+ Sync
+ 'static {
const NAME: &str;
const TYP: LazyLock<FnType>;
// Required method
fn finish(&mut self, slots: &[Slot<C, E>], a: &ValArray) -> Option<Value>;
}Required Associated Constants
Required Methods
Sourcefn finish(&mut self, slots: &[Slot<C, E>], a: &ValArray) -> Option<Value>
fn finish(&mut self, slots: &[Slot<C, E>], a: &ValArray) -> Option<Value>
finish will be called when every lambda instance has produced a value for the updated array. Out contains the output of the predicate lambda for each index i, and a is the array. out and a are guaranteed to have the same length. out[i].cur is guaranteed to be Some.
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".